==> wpewebkit_2.34.2.orig.tar.xz: wpewebkit-2.34.2/Source/WebCore/Modules/applepay/PaymentInstallmentConfigurationWebCore.h <==
/*
 * Copyright (C) 2019 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#if HAVE(PASSKIT_INSTALLMENTS)

#include <wtf/RetainPtr.h>

OBJC_CLASS NSDictionary;
OBJC_CLASS PKPaymentInstallmentConfiguration;

namespace WebCore {

class Document;
struct ApplePayInstallmentConfiguration;
template<typename> class ExceptionOr;

class WEBCORE_EXPORT PaymentInstallmentConfiguration {
public:
    static ExceptionOr<PaymentInstallmentConfiguration> create(const ApplePayInstallmentConfiguration&);

    PaymentInstallmentConfiguration() = default;
    PaymentInstallmentConfiguration(RetainPtr<PKPaymentInstallmentConfiguration>&&);

    PKPaymentInstallmentConfiguration *platformConfiguration() const;
    ApplePayInstallmentConfiguration applePayInstallmentConfiguration() const;

private:
    PaymentInstallmentConfiguration(const ApplePayInstallmentConfiguration&, NSDictionary *applicationMetadata);

    RetainPtr<PKPaymentInstallmentConfiguration> m_configuration;
};

} // namespace WebCore

#endif // HAVE(PASSKIT_INSTALLMENTS)

==> wpewebkit_2.46.5.orig.tar.xz: wpewebkit-2.46.5/Source/WebCore/Modules/applepay/PaymentInstallmentConfigurationWebCore.h <==
/*
 * Copyright (C) 2019 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#if HAVE(PASSKIT_INSTALLMENTS)

#include "ApplePayInstallmentConfigurationWebCore.h"
#include <wtf/RetainPtr.h>

OBJC_CLASS NSDictionary;
OBJC_CLASS PKPaymentInstallmentConfiguration;

namespace WebCore {

class Document;
template<typename> class ExceptionOr;

class WEBCORE_EXPORT PaymentInstallmentConfiguration {
public:
    static ExceptionOr<PaymentInstallmentConfiguration> create(const ApplePayInstallmentConfiguration&);

    PaymentInstallmentConfiguration() = default;
    PaymentInstallmentConfiguration(RetainPtr<PKPaymentInstallmentConfiguration>&&);
    PaymentInstallmentConfiguration(std::optional<ApplePayInstallmentConfiguration>&&);
    PaymentInstallmentConfiguration(const ApplePayInstallmentConfiguration&, RetainPtr<NSDictionary>&&);

    RetainPtr<PKPaymentInstallmentConfiguration> platformConfiguration() const;
    const std::optional<ApplePayInstallmentConfiguration>& applePayInstallmentConfiguration() const;

private:
    static std::optional<ApplePayInstallmentConfiguration> applePayInstallmentConfiguration(PKPaymentInstallmentConfiguration *);

    std::optional<ApplePayInstallmentConfiguration> m_configuration;
};

} // namespace WebCore

#endif // HAVE(PASSKIT_INSTALLMENTS)
